@@ -21,13 +21,14 @@
 
 import os
 import shlex
+import shutil
 import subprocess as sp
 import sys
 import typing as t
 from typing import cast, List, Optional, Set
 
 import click
-import networkx as nx
+import networkx as nx  # type: ignore
 
 from shut.model.package import PackageModel
 from shut.model.monorepo import InterdependencyRef
@@ -36,6 +37,10 @@ from . import pkg
 from .. import project
 
 
+def _join_command(cmd: t.List[str]) -> str:
+  return ' '.join(map(shlex.quote, cmd))
+
+
 def collect_requirement_args(
   package: PackageModel,
   develop: bool,
@@ -72,7 +77,7 @@ def collect_requirement_args(
     for dep_name in nx.algorithms.topological_sort(graph):
       dep = project_packages[dep_name]
       ref = direct_inter_dependencies[dep_name]
-      if not ref.version_selector.matches(dep.version):
+      if ref.version_selector and dep.version and not ref.version_selector.matches(dep.version):
         print('note: skipping inter-dependency on package "{}" because the version selector '
               '{} does not match the present version {}'
               .format(dep.name, ref.version_selector, dep.version), file=sys.stderr)
@@ -91,7 +96,17 @@ def run_install(
   dry: bool,
 ) -> None:
 
-  pip_bin = shlex.split(os.getenv('PIP', pip or 'python -m pip'))
+  if pip is None:
+    # NOTE (NiklasRosenstein): If we use just "python -m pip", for some reason on Windows, Pip
+    #   will kick off the build/install step with the system-wide Python installation even when
+    #   we're in a venv. Using the full path to the current python installation works as expected
+    #   though...
+    python = shutil.which('python')
+    assert python
+    pip = os.getenv('PIP', _join_command([python, '-m', 'pip']))
+
+  assert pip
+  pip_bin = shlex.split(pip)
   command = pip_bin + ['install'] + args
   if upgrade:
     command.append('--upgrade')
@@ -133,11 +148,11 @@ def install(develop, dev, test, inter_deps, extra, upgrade, quiet, verbose, pip,
   The command used to invoke Pip can be overwritten using the `PIP` environment variable.
   """
 
-  if extra is None: extra = []
+  if extra is None: extra = set()
   if dev is None: dev = develop
   if test is None: test = develop
-  if dev: extra += ['dev']
-  if test: extra += ['test']
+  if dev: extra.add('dev')
+  if test: extra.add('test')
 
   if not pip and pipx:
     pip = 'pipx'
